@@ -23,13 +23,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
- * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
-#ifndef __OPAL_H450PDU_H
-#define __OPAL_H450PDU_H
+#ifndef OPAL_H323_H450PDU_H
+#define OPAL_H323_H450PDU_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -37,6 +37,8 @@
 
 #include <opal/buildopts.h>
 
+#if OPAL_H450
+
 #include <asn/x880.h>
 #include <asn/h4501.h>
 #include <asn/h4502.h>
@@ -920,7 +922,9 @@ class H45011Handler : public H450xHandler
 };
 
 
-#endif // __OPAL_H450PDU_H
+#endif // OPAL_H450
+
+#endif // OPAL_H323_H450PDU_H
 
 
 /////////////////////////////////////////////////////////////////////////////
