@@ -23,18 +23,21 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 19279 $
- * $Author: rjongbloed $
- * $Date: 2008-01-17 05:08:34 +0100 (jeu 17 jan 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
-#ifndef __OPAL_PECLIENT_H
-#define __OPAL_PECLIENT_H
+#ifndef OPAL_H323_PECLIENT_H
+#define OPAL_H323_PECLIENT_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
 #endif
 
+#include <opal/buildopts.h>
+
+#if OPAL_H501
 
 #include <h323/h323annexg.h>
 #include <h323/h323ep.h>
@@ -182,7 +185,7 @@ class H323PeerElementDescriptor : public PSafeObject
     };
 
     static inline unsigned SetPriorityOption(unsigned pri)     { return Option_PrioritySet | ((pri & 0x7f) << 6); }
-    static inline unsigned GetPriorityOption(unsigned options) { return (options & Option_PrioritySet) ? ((options >> 6) & 0x7f) : DefaultPriority; }
+    static inline unsigned GetPriorityOption(unsigned options) { return (options & Option_PrioritySet) != 0 ? ((options >> 6) & 0x7f) : (int)DefaultPriority; }
 
     void CopyTo(H501_Descriptor & descriptor);
     static PBoolean CopyToAddressTemplate(H501_AddressTemplate & addressTemplates, 
@@ -527,7 +530,9 @@ class H323PeerElement : public H323_AnnexG
 };
 
 
-#endif // __OPAL_PECLIENT_H
+#endif // OPAL_H501
+
+#endif // OPAL_H323_PECLIENT_H
 
 
 /////////////////////////////////////////////////////////////////////////////
