@@ -24,83 +24,22 @@
  *
  * The author of this code is Derek J Smithies
  *
- *
- *  $Log: callprocessor.h,v $
- *  Revision 1.9  2007/04/19 06:17:21  csoutheren
- *  Fixes for precompiled headers with gcc
- *
- *  Revision 1.8  2007/01/18 04:45:16  csoutheren
- *  Messy, but simple change to add additional options argument to OpalConnection constructor
- *  This allows the provision of non-trivial arguments for connections
- *
- *  Revision 1.7  2007/01/17 22:27:52  dereksmithies
- *  Correctly sends DTMF to remote node. Tidy up string handling.
- *
- *  Revision 1.6  2007/01/17 03:48:13  dereksmithies
- *  Tidy up comments, remove leaks, improve reporting of packet types.
- *
- *  Revision 1.5  2007/01/16 03:17:42  dereksmithies
- *  tidyup of comments. Remove unused variables.
- *  Guarantee that media frames are sent with a monotonically increasing timestamp
- *
- *  Revision 1.4  2007/01/11 03:02:15  dereksmithies
- *  Remove the previous audio buffering code, and switch to using the jitter
- *  buffer provided in Opal. Reduce the verbosity of the log mesasges.
- *
- *  Revision 1.3  2006/09/22 00:33:19  csoutheren
- *  Changed PAtomicInteger to PBoolean
- *
- *  Revision 1.2  2006/09/11 03:08:51  dereksmithies
- *  Add fixes from Stephen Cook (sitiveni@gmail.com) for new patches to
- *  improve call handling. Notably, IAX2 call transfer. Many thanks.
- *  Thanks also to the Google summer of code for sponsoring this work.
- *
- *  Revision 1.1  2006/08/09 03:46:39  dereksmithies
- *  Add ability to register to a remote Asterisk box. The iaxProcessor class is split
- *  into a callProcessor and a regProcessor class.
- *  Big thanks to Stephen Cook, (sitiveni@gmail.com) for this work.
- *
- *  Revision 1.7  2005/09/05 01:19:43  dereksmithies
- *  add patches from Adrian Sietsma to avoid multiple hangup packets at call end,
- *  and stop the sending of ping/lagrq packets at call end. Many thanks.
- *
- *  Revision 1.6  2005/08/26 03:07:38  dereksmithies
- *  Change naming convention, so all class names contain the string "IAX2"
- *
- *  Revision 1.5  2005/08/25 03:26:06  dereksmithies
- *  Add patch from Adrian Sietsma to correctly set the packet timestamps under windows.
- *  Many thanks.
- *
- *  Revision 1.4  2005/08/24 04:56:25  dereksmithies
- *  Add code from Adrian Sietsma to send FullFrameTexts and FullFrameDtmfs to
- *  the remote end.  Many Thanks.
- *
- *  Revision 1.3  2005/08/24 01:38:38  dereksmithies
- *  Add encryption, iax2 style. Numerous tidy ups. Use the label iax2, not iax
- *
- *  Revision 1.2  2005/08/04 08:14:17  rjongbloed
- *  Fixed Windows build under DevStudio 2003 of IAX2 code
- *
- *  Revision 1.1  2005/07/30 07:01:32  csoutheren
- *  Added implementation of IAX2 (Inter Asterisk Exchange 2) protocol
- *  Thanks to Derek Smithies of Indranet Technologies Ltd. for
- *  writing and contributing this code
- *
- *
- *
- *
- *
- *
- *
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
-#ifndef CALLPROCESSOR_H
-#define CALLPROCESSOR_H
+#ifndef OPAL_IAX2_CALLPROCESSOR_H
+#define OPAL_IAX2_CALLPROCESSOR_H
 
 #ifndef _PTLIB_H
 #include <ptlib.h>
 #endif
 
+#include <opal/buildopts.h>
+
+#if OPAL_IAX2
+
 #include <opal/connection.h>
 
 #include <iax2/processor.h>
@@ -752,4 +691,6 @@ class IAX2CallProcessor : public IAX2Processor
  */
 
 
-#endif // CALLPROCESSOR_H
+#endif // OPAL_IAX2
+
+#endif // OPAL_IAX2_CALLPROCESSOR_H
