@@ -27,21 +27,24 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
- * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
-#ifndef __OPAL_IAX_H
-#define __OPAL_IAX_H
+#ifndef OPAL_IAX2_IAX2_H
+#define OPAL_IAX2_IAX2_H
 
 #include <opal/buildopts.h>
 
+#if OPAL_IAX2
+
 #include <iax2/iax2ep.h>
 #include <iax2/iax2con.h>
 
+#endif // OPAL_IAX2
 
-#endif // __OPAL_IAX_H
+#endif // OPAL_IAX2_IAX2_H
 
 
 // End of File ///////////////////////////////////////////////////////////////
