@@ -25,13 +25,13 @@
  *
  * The author of this code is Derek J Smithies
  *
- * $Revision: 21004 $
- * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
-#ifndef __OPAL_IAX2_MEDIASTRM_H
-#define __OPAL_IAX2_MEDIASTRM_H
+#ifndef OPAL_IAX2_MEDIASTRM_H
+#define OPAL_IAX2_MEDIASTRM_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -39,6 +39,8 @@
 
 #include <opal/buildopts.h>
 
+#if OPAL_IAX2
+
 #include <opal/mediafmt.h>
 #include <iax2/iax2con.h>
 #include <iax2/iax2jitter.h>
@@ -123,7 +125,10 @@ class OpalIAX2MediaStream : public OpalMediaStream
     PBYTEArray pendingData;
 };
 
-#endif  //__OPAL_IAX2_MEDIASTRM_H
+
+#endif // OPAL_IAX2
+
+#endif  // OPAL_IAX2_MEDIASTRM_H
 
 /* The comment below is magic for those who use emacs to edit this file. */
 /* With the comment below, the tab key does auto indent to 2 spaces.     */
@@ -135,4 +140,3 @@ class OpalIAX2MediaStream : public OpalMediaStream
  * c-basic-offset:2
  * End:
  */
-
