@@ -26,13 +26,13 @@
  * 
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
- * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
-#ifndef __LIDS_LIDEP_H
-#define __LIDS_LIDEP_H
+#ifndef OPAL_LIDS_LIDEP_H
+#define OPAL_LIDS_LIDEP_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -483,6 +483,12 @@ class OpalLineConnection : public OpalConnection
   //@}
 
 
+  /**@name Member variable access */
+  //@{
+    /**Get the line being used by this media stream.
+      */
+    OpalLine & GetLine() { return line; }
+
     /** delay in msec to wait between the dial tone detection and dialing the dtmf 
       * @param uiDial the dial delay to set
      */
@@ -492,7 +498,7 @@ class OpalLineConnection : public OpalConnection
      * @return uiDialDelay the dial delay to get
      */
     unsigned int getDialDelay() const { return m_dialParams.m_dialStartDelay; }
-
+  //@}
         
   protected:
     OpalLineEndPoint & endpoint;
@@ -658,7 +664,7 @@ class OpalLineSilenceDetector : public OpalSilenceDetector
 };
 
 
-#endif // __LIDS_LIDEP_H
+#endif // OPAL_LIDS_LIDEP_H
 
 
 // End of File ///////////////////////////////////////////////////////////////
