@@ -24,18 +24,20 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20660 $
- * $Author: rjongbloed $
- * $Date: 2008-08-13 03:58:41 +0200 (mer 13 aoû 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
-#ifndef __LIDPLUGINMGR_H
-#define __LIDPLUGINMGR_H
+#ifndef OPAL_LIDS_LIDPLUGINMGR_H
+#define OPAL_LIDS_LIDPLUGINMGR_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
 #endif
 
+#include <opal/buildopts.h>
+
 #include <ptlib/pluginmgr.h>
 #include <ptlib/sound.h>
 #include <lids/lidplugin.h>
@@ -661,4 +663,4 @@ class OpalPluginLID : public OpalLineInterfaceDevice
 };
 
 
-#endif // __LIDPLUGINMGR_H
+#endif // OPAL_LIDS_LIDPLUGINMGR_H
