@@ -23,23 +23,25 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 19279 $
- * $Author: rjongbloed $
- * $Date: 2008-01-17 05:08:34 +0100 (jeu 17 jan 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
-#ifndef __OPAL_GUID_H
-#define __OPAL_GUID_H
+#ifndef OPAL_OPAL_GUID_H
+#define OPAL_OPAL_GUID_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
 #endif
 
+#include <opal/buildopts.h>
+
 #include <ptclib/guid.h>
 
 #define OpalGloballyUniqueID PGloballyUniqueID
 
-#endif // __OPAL_GUID_H
+#endif // OPAL_OPAL_GUID_H
 
 
 /////////////////////////////////////////////////////////////////////////////
