@@ -24,14 +24,14 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
- * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 
-#ifndef _OPALMIXER_H
-#define _OPALMIXER_H
+#ifndef OPAL_OPAL_OPALMIXER_H
+#define OPAL_OPAL_OPALMIXER_H
 
 #ifndef _PTLIB_H
 #include <ptlib.h>
@@ -364,5 +364,5 @@ class OpalAudioMixer
     PBoolean Write(const Key_T & key, const RTP_DataFrame & rtp);
 };
 
-#endif // _OPAL_MIXER
+#endif // OPAL_OPAL_OPAL_MIXER
 
