@@ -26,13 +26,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21035 $
- * $Author: rjongbloed $
- * $Date: 2008-09-17 07:57:58 +0000 (Wed, 17 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
-#ifndef __OPAL_SRTP_H
-#define __OPAL_SRTP_H
+#ifndef OPAL_RTP_SRTP_H
+#define OPAL_RTP_SRTP_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -142,4 +142,4 @@ class LibSRTP_UDP : public OpalSRTP_UDP
 
 #endif // OPAL_SRTP
 
-#endif // __OPAL_SRTP_H
+#endif // OPAL_RTP_SRTP_H
