@@ -23,13 +23,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
- * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
-#ifndef __OPAL_T120PROTO_H
-#define __OPAL_T120PROTO_H
+#ifndef OPAL_T120_T120PROTO_H
+#define OPAL_T120_T120PROTO_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -37,6 +37,8 @@
 
 #include <opal/buildopts.h>
 
+#if OPAL_T120DATA
+
 #include <opal/mediafmt.h>
 
 
@@ -102,7 +104,9 @@ class OpalT120Protocol : public PObject
 };
 
 
-#endif // __OPAL_T120PROTO_H
+#endif // OPAL_T120DATA
+
+#endif // OPAL_T120_T120PROTO_H
 
 
 /////////////////////////////////////////////////////////////////////////////
