@@ -25,16 +25,24 @@
  */
 
 /*
- * g726_24.c
+ * g726_40.c
  *
  * Description:
  *
- * g723_24_encoder(), g723_24_decoder()
+ * g723_40_encoder(), g723_40_decoder()
  *
- * These routines comprise an implementation of the CCITT G.723 24 Kbps
+ * These routines comprise an implementation of the CCITT G.723 40Kbps
  * ADPCM coding algorithm.  Essentially, this implementation is identical to
- * the bit level description except for a few deviations which take advantage
- * of workstation attributes, such as hardware 2's complement arithmetic.
+ * the bit level description except for a few deviations which
+ * take advantage of workstation attributes, such as hardware 2's
+ * complement arithmetic.
+ *
+ * The deviation from the bit level specification (lookup tables),
+ * preserves the bit level performance specifications.
+ *
+ * As outlined in the G.723 Recommendation, the algorithm is broken
+ * down into modules.  Each section of code below is preceded by
+ * the name of the module which it is implementing.
  *
  * The ITU-T G.726 coder is an adaptive differential pulse code modulation
  * (ADPCM) waveform coding algorithm, suitable for coding of digitized
@@ -46,46 +54,58 @@
  * 2:1 over the G.711 format. For 24 kbps 40 kbps operation, the quantized
  * difference signal is 3 bits and 5 bits, respectively.
  *
- * $Revision: 18922 $
- * $Author: rjongbloed $
- * $Date: 2007-11-21 22:46:57 +0000 (Wed, 21 Nov 2007) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
+
 #include "g72x.h"
 #include "private.h"
 
 /*
- * Maps G.723_24 code word to reconstructed scale factor normalized log
+ * Maps G.723_40 code word to ructeconstructed scale factor normalized log
  * magnitude values.
  */
-static short	_dqlntab[8] = {-2048, 135, 273, 373, 373, 273, 135, -2048};
+static short	_dqlntab[32] = {-2048, -66, 28, 104, 169, 224, 274, 318,
+				358, 395, 429, 459, 488, 514, 539, 566,
+				566, 539, 514, 488, 459, 429, 395, 358,
+				318, 274, 224, 169, 104, 28, -66, -2048};
 
-/* Maps G.723_24 code word to log of scale factor multiplier. */
-static short	_witab[8] = {-128, 960, 4384, 18624, 18624, 4384, 960, -128};
+/* Maps G.723_40 code word to log of scale factor multiplier. */
+static short	_witab[32] = {448, 448, 768, 1248, 1280, 1312, 1856, 3200,
+			4512, 5728, 7008, 8960, 11456, 14080, 16928, 22272,
+			22272, 16928, 14080, 11456, 8960, 7008, 5728, 4512,
+			3200, 1856, 1312, 1280, 1248, 768, 448, 448};
 
 /*
- * Maps G.723_24 code words to a set of values whose long and short
+ * Maps G.723_40 code words to a set of values whose long and short
  * term averages are computed and then compared to give an indication
  * how stationary (steady state) the signal is.
  */
-static short	_fitab[8] = {0, 0x200, 0x400, 0xE00, 0xE00, 0x400, 0x200, 0};
+static short	_fitab[32] = {0, 0, 0, 0, 0, 0x200, 0x200, 0x200,
+			0x200, 0x200, 0x400, 0x600, 0x800, 0xA00, 0xC00, 0xC00,
+			0xC00, 0xC00, 0xA00, 0x800, 0x600, 0x400, 0x200, 0x200,
+			0x200, 0x200, 0x200, 0, 0, 0, 0, 0};
 
-static int qtab_723_24[3] = {8, 218, 331};
+static int qtab_723_40[15] = {-122, -16, 68, 139, 198, 250, 298, 339,
+				378, 413, 445, 475, 502, 528, 553};
 
 /*
- * g723_24_encoder()
+ * g723_40_encoder()
  *
- * Encodes a linear PCM, A-law or u-law input sample and returns its 3-bit code.
- * Returns -1 if invalid input coding value.
+ * Encodes a 16-bit linear PCM, A-law or u-law input sample and returns
+ * the resulting 5-bit CCITT G.723 40Kbps code.
+ * Returns -1 if the input coding value is invalid.
  */
 int
-g726_24_encoder(
+g726_40_encoder(
 	int		sl,
 	int		in_coding,
 	g726_state *state_ptr)
 {
 	int		sezi;
-	int		sei;
 	int		sez;			/* ACCUM */
+	int		sei;
 	int		se;
 	int		d;				/* SUBTA */
 	int		y;				/* MIX */
@@ -113,31 +133,32 @@ g726_24_encoder(
 	sei = sezi + predictor_pole(state_ptr);
 	se = sei >> 1;			/* se = estimated signal */
 
-	d = sl - se;			/* d = estimation diff. */
+	d = sl - se;			/* d = estimation difference */
 
-	/* quantize prediction difference d */
-	y = step_size(state_ptr);	/* quantizer step size */
-	i = quantize(d, y, qtab_723_24, 3);	/* i = ADPCM code */
-	dq = reconstruct(i & 4, _dqlntab[i], y); /* quantized diff. */
+	/* quantize prediction difference */
+	y = step_size(state_ptr);	/* adaptive quantizer step size */
+	i = quantize(d, y, qtab_723_40, 15);	/* i = ADPCM code */
 
-	sr = (dq < 0) ? se - (dq & 0x3FFF) : se + dq; /* reconstructed signal */
+	dq = reconstruct(i & 0x10, _dqlntab[i], y);	/* quantized diff */
 
-	dqsez = sr + sez - se;		/* pole prediction diff. */
+	sr = (dq < 0) ? se - (dq & 0x7FFF) : se + dq; /* reconstructed signal */
 
-	update(3, y, _witab[i], _fitab[i], dq, sr, dqsez, state_ptr);
+	dqsez = sr + sez - se;		/* dqsez = pole prediction diff. */
+
+	update(5, y, _witab[i], _fitab[i], dq, sr, dqsez, state_ptr);
 
 	return (i);
 }
 
 /*
- * g723_24_decoder()
+ * g723_40_decoder()
  *
- * Decodes a 3-bit CCITT G.723_24 ADPCM code and returns
+ * Decodes a 5-bit CCITT G.723 40Kbps code and returns
  * the resulting 16-bit linear PCM, A-law or u-law sample value.
  * -1 is returned if the output coding is unknown.
  */
 int
-g726_24_decoder(
+g726_40_decoder(
 	int		i,
 	int		out_coding,
 	g726_state *state_ptr)
@@ -151,26 +172,26 @@ g726_24_decoder(
 	int		sr;				/* ADDB */
 	int		dqsez;
 
-	i &= 0x07;				/* mask to get proper bits */
+	i &= 0x1f;				/* mask to get proper bits */
 	sezi = predictor_zero(state_ptr);
 	sez = sezi >> 1;
 	sei = sezi + predictor_pole(state_ptr);
 	se = sei >> 1;			/* se = estimated signal */
 
 	y = step_size(state_ptr);	/* adaptive quantizer step size */
-	dq = reconstruct(i & 0x04, _dqlntab[i], y); /* unquantize pred diff */
+	dq = reconstruct(i & 0x10, _dqlntab[i], y);	/* estimation diff. */
 
-	sr = (dq < 0) ? (se - (dq & 0x3FFF)) : (se + dq); /* reconst. signal */
+	sr = (dq < 0) ? (se - (dq & 0x7FFF)) : (se + dq); /* reconst. signal */
 
-	dqsez = sr - se + sez;			/* pole prediction diff. */
+	dqsez = sr - se + sez;		/* pole prediction diff. */
 
-	update(3, y, _witab[i], _fitab[i], dq, sr, dqsez, state_ptr);
+	update(5, y, _witab[i], _fitab[i], dq, sr, dqsez, state_ptr);
 
 	switch (out_coding) {
 	case AUDIO_ENCODING_ALAW:
-		return (tandem_adjust_alaw(sr, se, y, i, 4, qtab_723_24));
+		return (tandem_adjust_alaw(sr, se, y, i, 0x10, qtab_723_40));
 	case AUDIO_ENCODING_ULAW:
-		return (tandem_adjust_ulaw(sr, se, y, i, 4, qtab_723_24));
+		return (tandem_adjust_ulaw(sr, se, y, i, 0x10, qtab_723_40));
 	case AUDIO_ENCODING_LINEAR:
 		return (sr << 2);	/* sr was of 14-bit dynamic range */
 	default:
