@@ -21,9 +21,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
- * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #ifndef _OpalGw_MAIN_H
@@ -185,6 +185,8 @@ class OpalGw : public OpalGwProcessAncestor
 };
 
 
+#if OPAL_H323
+
 class MainStatusPage : public PServiceHTTPString
 {
   PCLASSINFO(MainStatusPage, PServiceHTTPString);
@@ -202,6 +204,8 @@ class MainStatusPage : public PServiceHTTPString
     OpalGw & app;
 };
 
+#endif // OPAL_H323
+
 
 #endif  // _OpalGw_MAIN_H
 
