@@ -23,16 +23,16 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 19279 $
- * $Author: rjongbloed $
- * $Date: 2008-01-17 05:08:34 +0100 (jeu 17 jan 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #include <ptlib.h>
 
 #include <opal/manager.h>
 
-#if P_SSL
+#if OPAL_PTLIB_SSL
 #include <ptclib/shttpsvc.h>
 typedef PSecureHTTPServiceProcess OpalGwProcessAncestor;
 #else
@@ -52,7 +52,7 @@ typedef PHTTPServiceProcess OpalGwProcessAncestor;
 
 #include <lids/lidep.h>
 
-#if P_EXPAT
+#if OPAL_IVR
 #include <opal/ivr.h>
 #endif
 
