@@ -24,9 +24,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21032 $
- * $Author: rjongbloed $
- * $Date: 2008-09-17 06:23:59 +0000 (Wed, 17 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #ifndef _OpenPhone_MAIN_H
@@ -48,17 +48,8 @@
 
 #include <opal/pcss.h>
 
-#ifndef OPAL_H323
-#error Must compile with H.323 enabled!
-#endif
-
 #include <h323/h323.h>
 #include <h323/gkclient.h>
-
-#ifndef OPAL_SIP
-#error Must compile with SIP enabled!
-#endif
-
 #include <sip/sip.h>
 
 
@@ -152,6 +143,8 @@ class MyH323EndPoint : public H323EndPoint
 };
 #endif
 
+
+#if OPAL_SIP
 class MySIPEndPoint : public SIPEndPoint
 {
   public:
@@ -174,6 +167,22 @@ class MySIPEndPoint : public SIPEndPoint
 
     MyManager & m_manager;
 };
+#endif // OPAL_SIP
+
+
+class VideoControlDialog : public wxDialog
+{
+  public:
+    VideoControlDialog(MyManager * manager);
+
+  private:
+    bool TransferDataFromWindow();
+
+    MyManager & m_manager;
+    wxSlider  * m_TargetBitRate;
+
+    DECLARE_EVENT_TABLE()
+};
 
 
 class CallDialog : public wxDialog
@@ -246,6 +255,7 @@ struct StatisticsField
   void Init(wxWindow * panel);
   void Clear();
   double CalculateBandwidth(DWORD bytes);
+  double CalculateFrameRate(DWORD frames);
   virtual StatisticsField * Clone() const = 0;
   virtual void Update(const OpalConnection & connection, const OpalMediaStream & stream);
   virtual void GetValue(const OpalConnection & connection, const OpalMediaStream & stream, const OpalMediaStatistics & statistics, wxString & value) = 0;
@@ -255,8 +265,11 @@ struct StatisticsField
   wxStaticText  * m_staticText;
   wxString        m_printFormat;
 
-  PTimeInterval   m_lastTick;
+  PTimeInterval   m_lastBandwidthTick;
   DWORD           m_lastBytes;
+
+  PTimeInterval   m_lastFrameTick;
+  DWORD           m_lastFrames;
 };
 
 class StatisticsPage
@@ -266,10 +279,10 @@ class StatisticsPage
     ~StatisticsPage();
 
     void Init(
-      InCallPanel   * panel,
-      StatisticsPages page,
-      const char    * mediaType,
-      bool            receiver
+      InCallPanel         * panel,
+      StatisticsPages       page,
+      const OpalMediaType & mediaType,
+      bool                  receiver
     );
 
     void UpdateSession(const OpalConnection * connection);
@@ -497,6 +510,8 @@ class OptionsDialog : public wxDialog
     PwxString m_VideoMinFrameSize;
     PwxString m_VideoMaxFrameSize;
 
+    void TestVideoCapture(wxCommandEvent & event);
+
     ////////////////////////////////////////
     // Fax fields
     PwxString m_FaxStationIdentifier;
@@ -643,7 +658,7 @@ public:
 
   bool operator<(const MyMedia & other) { return preferenceOrder < other.preferenceOrder; }
 
-  const wxChar    * sourceProtocol;
+  const wxString  sourceProtocol;
   OpalMediaFormat mediaFormat;
   const wxChar    * validProtocols;
   int             preferenceOrder;
@@ -769,6 +784,7 @@ class MyManager : public wxFrame, public OpalManager
     void OnStartVideo(wxCommandEvent& event);
     void OnStopVideo(wxCommandEvent& event);
     void OnVFU(wxCommandEvent& event);
+    void OnVideoControl(wxCommandEvent& event);
     void OnSashPositioned(wxSplitterEvent& event);
     void OnSpeedDialActivated(wxListEvent& event);
     void OnSpeedDialColumnResize(wxListEvent& event);
@@ -836,11 +852,13 @@ class MyManager : public wxFrame, public OpalManager
 #endif
     bool StartGatekeeper();
 
+#if OPAL_SIP
     MySIPEndPoint * sipEP;
     bool            m_SIPProxyUsed;
     RegistrarList   m_registrars;
     void StartRegistrars();
     void StopRegistrars();
+#endif
 
 #if OPAL_IVR
     OpalIVREndPoint  * ivrEP;
