@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20881 $
- * $Author: rjongbloed $
- * $Date: 2008-09-07 08:13:03 +0000 (Sun, 07 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #include <ptlib.h>
@@ -383,9 +383,11 @@ void H323UnidirectionalChannel::Close()
   PTRACE(4, "H323RTP\tCleaning up media stream on " << number);
 
   // If we have source media stream close it
-  connection.CloseMediaStream(*mediaStream);
-  connection.RemoveMediaStream(*mediaStream);
-  mediaStream.SetNULL();
+  if (mediaStream != NULL) {
+    connection.CloseMediaStream(*mediaStream);
+    connection.RemoveMediaStream(*mediaStream);
+    mediaStream.SetNULL();
+  }
 
   H323Channel::Close();
 }
@@ -442,7 +444,7 @@ void H323UnidirectionalChannel::OnMediaCommand(OpalMediaCommand & command)
     H323ControlPDU pdu;
     const OpalVideoUpdatePicture & updatePicture = (const OpalVideoUpdatePicture &)command;
 
-    if (updatePicture.GetNumBlocks() < 0)
+    if (updatePicture.GetNumBlocks() <= 0)
       pdu.BuildMiscellaneousCommand(GetNumber(), H245_MiscellaneousCommand_type::e_videoFastUpdatePicture);
     else if (updatePicture.GetFirstMB() < 0) {
       H245_MiscellaneousCommand_type_videoFastUpdateGOB & fuGOB = 
