@@ -26,9 +26,9 @@
  *
  * Contributor(s): Many thanks to Simon Horne.
  *
- * $Revision: 20352 $
- * $Author: rjongbloed $
- * $Date: 2008-06-01 09:30:08 +0200 (dim 01 jun 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #include <ptlib.h>
@@ -117,7 +117,7 @@ H323EndPoint::H323EndPoint(OpalManager & manager)
 
   secondaryConnectionsActive.DisallowDeleteObjects();
   
-#ifdef OPAL_H460
+#if OPAL_H460
   disableH460 = FALSE;
 #endif
 
@@ -144,7 +144,7 @@ void H323EndPoint::ShutDown()
 PString H323EndPoint::GetDefaultTransport() const
 {
   return "tcp$"
-#ifdef P_SSL
+#if OPAL_PTLIB_SSL
          ",tcps$:1300"
 #endif
     ;
@@ -324,9 +324,8 @@ PBoolean H323EndPoint::UseGatekeeper(const PString & address,
 
 PBoolean H323EndPoint::SetGatekeeper(const PString & address, H323Transport * transport)
 {
-  H323Gatekeeper * gk = InternalCreateGatekeeper(transport);
   H323TransportAddress h323addr(address, H225_RAS::DefaultRasUdpPort, "udp");
-  return InternalRegisterGatekeeper(gk, gk->DiscoverByAddress(h323addr));
+  return InternalCreateGatekeeper(transport) && gatekeeper->DiscoverByAddress(h323addr);
 }
 
 
@@ -334,57 +333,36 @@ PBoolean H323EndPoint::SetGatekeeperZone(const PString & address,
                                      const PString & identifier,
                                      H323Transport * transport)
 {
-  H323Gatekeeper * gk = InternalCreateGatekeeper(transport);
   H323TransportAddress h323addr(address, H225_RAS::DefaultRasUdpPort, "udp");
-  return InternalRegisterGatekeeper(gk, gk->DiscoverByNameAndAddress(identifier, h323addr));
+  return InternalCreateGatekeeper(transport) && gatekeeper->DiscoverByNameAndAddress(identifier, h323addr);
 }
 
 
 PBoolean H323EndPoint::LocateGatekeeper(const PString & identifier, H323Transport * transport)
 {
-  H323Gatekeeper * gk = InternalCreateGatekeeper(transport);
-  return InternalRegisterGatekeeper(gk, gk->DiscoverByName(identifier));
+  return InternalCreateGatekeeper(transport) && gatekeeper->DiscoverByName(identifier);
 }
 
 
 PBoolean H323EndPoint::DiscoverGatekeeper(H323Transport * transport)
 {
-  H323Gatekeeper * gk = InternalCreateGatekeeper(transport);
-  return InternalRegisterGatekeeper(gk, gk->DiscoverAny());
+  return InternalCreateGatekeeper(transport) && gatekeeper->DiscoverAny();
 }
 
 
-H323Gatekeeper * H323EndPoint::InternalCreateGatekeeper(H323Transport * transport)
+bool H323EndPoint::InternalCreateGatekeeper(H323Transport * transport)
 {
   RemoveGatekeeper(H225_UnregRequestReason::e_reregistrationRequired);
 
   if (transport == NULL)
     transport = new H323TransportUDP(*this);
 
+  gatekeeper = CreateGatekeeper(transport);
+  if (gatekeeper == NULL)
+    return false;
 
-  H323Gatekeeper * gk = CreateGatekeeper(transport);
-
-  gk->SetPassword(gatekeeperPassword, gatekeeperUsername);
-
-  return gk;
-}
-
-
-PBoolean H323EndPoint::InternalRegisterGatekeeper(H323Gatekeeper * gk, PBoolean discovered)
-{
-  if (discovered) {
-    if (gk->RegistrationRequest()) {
-      gatekeeper = gk;
-      return PTrue;
-    }
-
-    // RRQ was rejected continue trying
-    gatekeeper = gk;
-  }
-  else // Only stop listening if the GRQ was rejected
-    delete gk;
-
-  return PFalse;
+  gatekeeper->SetPassword(gatekeeperPassword, gatekeeperUsername);
+  return true;
 }
 
 
@@ -431,7 +409,7 @@ void H323EndPoint::SetGatekeeperPassword(const PString & password, const PString
     gatekeeper->SetPassword(gatekeeperPassword, gatekeeperUsername);
     if (gatekeeper->IsRegistered()) // If we are registered send a URQ
       gatekeeper->UnregistrationRequest(H225_UnregRequestReason::e_reregistrationRequired);
-    InternalRegisterGatekeeper(gatekeeper, PTrue);
+    gatekeeper->RegistrationRequest();
   }
 }
 
@@ -751,7 +729,7 @@ PBoolean H323EndPoint::ParsePartyName(const PString & remoteParty,
 {
   PURL url(remoteParty, GetPrefixName()); // Parses as per RFC3508
 
-#if P_DNS
+#if OPAL_PTLIB_DNS
 
   // if there is no gatekeeper, try altarnate address lookup methods
   if (gatekeeper == NULL) {
@@ -805,7 +783,7 @@ PBoolean H323EndPoint::ParsePartyName(const PString & remoteParty,
   if (url.GetScheme() == "callto") {
     // Do not yet support ILS
     if (type == "directory") {
-#if P_LDAP
+#if OPAL_PTLIB_LDAP
       PString server = url.GetHostName();
       if (server.IsEmpty())
         server = GetDefaultILSServer();
@@ -1187,6 +1165,13 @@ H323ServiceControlSession * H323EndPoint::CreateServiceControlSession(const H225
 }
 
 
+void H323EndPoint::SetDefaultLocalPartyName(const PString & name)
+{
+  SetLocalUserName(name);
+  OpalEndPoint::SetDefaultLocalPartyName(name);
+}
+
+
 void H323EndPoint::SetLocalUserName(const PString & name)
 {
   PAssert(!name, "Must have non-empty string in AliasAddress!");
@@ -1305,7 +1290,7 @@ void H323EndPoint::TranslateTCPAddress(PIPSocket::Address & localAddr,
 
 PBoolean H323EndPoint::OnSendFeatureSet(unsigned id, H225_FeatureSet & featureSet)
 {
-#ifdef H323_H460
+#if OPAL_H460
   return features.SendFeature(id, featureSet);
 #else
   return false;
@@ -1315,7 +1300,7 @@ PBoolean H323EndPoint::OnSendFeatureSet(unsigned id, H225_FeatureSet & featureSe
 
 void H323EndPoint::OnReceiveFeatureSet(unsigned id, const H225_FeatureSet & featureSet)
 {
-#ifdef H323_H460
+#if OPAL_H460
   features.ReceiveFeature(id, featureSet);
 #endif
 }
@@ -1323,7 +1308,7 @@ void H323EndPoint::OnReceiveFeatureSet(unsigned id, const H225_FeatureSet & feat
 
 void H323EndPoint::LoadBaseFeatureSet()
 {
-#ifdef H323_H460
+#if OPAL_H460
   features.AttachEndPoint(this);
   features.LoadFeatureSet(H460_Feature::FeatureBase);
 #endif
