@@ -33,9 +33,9 @@
  *
  * Contributor(s): Many thanks to Simon Horne.
  *
- * $Revision: 20651 $
- * $Author: rjongbloed $
- * $Date: 2008-08-11 04:59:27 +0200 (lun 11 aoû 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #include <ptlib.h>
@@ -44,6 +44,8 @@
 #pragma implementation "h4601.h"
 #endif
 
+#include <opal/buildopts.h>
+
 #include "h460/h460.h"
 
 #if OPAL_H460
