@@ -33,17 +33,20 @@
  *
  * Contributor(s): Many thanks to Simon Horne.
  *
- * $Revision: 20651 $
- * $Author: rjongbloed $
- * $Date: 2008-08-11 04:59:27 +0200 (lun 11 aoû 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #include <ptlib.h>
+
+#include <opal/buildopts.h>
+
 #include <h323/h323pdu.h>
 #include <h460/h460p.h>
 
 
-#ifdef OPAL_H460
+#if OPAL_H460
 
 static struct {
   unsigned id;
