@@ -28,13 +28,16 @@
  * The processor parts were abstracted out by  by Stephen Cook (sitiveni@gmail.com)
  * and this work was sponsored by the Google summer of code 
  *
- * $Revision: 21004 $
- * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #include <ptlib.h>
 #include <opal/buildopts.h>
+
+#if OPAL_IAX2
+
 #include <typeinfo>
 
 #ifdef P_USE_PRAGMA
@@ -460,3 +463,6 @@ void IAX2Processor::ReportLists(PString & answer)
 {
   answer= PString(" Incoming size ") + PString(frameList.GetSize());
 }
+
+
+#endif // OPAL_IAX2
