@@ -24,9 +24,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21159 $
- * $Author: rjongbloed $
- * $Date: 2008-09-25 03:12:55 +0000 (Thu, 25 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #include <ptlib.h>
@@ -445,11 +445,11 @@ void OpalConnection::AnsweringCall(AnswerCallResponse response)
   PTRACE(3, "OpalCon\tAnswering call: " << response);
 
   PSafeLockReadWrite safeLock(*this);
-  if (!safeLock.IsLocked() || GetPhase() >= ReleasingPhase)
+  if (!safeLock.IsLocked())
     return;
 
-  // Can only answer call in these two phases
-  if (GetPhase() != SetUpPhase && GetPhase() != AlertingPhase)
+  // Can't answer call if already answered
+  if (GetPhase() >= ConnectedPhase)
     return;
 
   switch (response) {
