@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21004 $
- * $Author: rjongbloed $
- * $Date: 2008-09-16 07:08:56 +0000 (Tue, 16 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #include <ptlib.h>
@@ -243,12 +243,16 @@ void OpalRTPConnection::SetSecurityData(void *data)
 void OpalRTPConnection::OnMediaCommand(OpalMediaCommand & command, INT /*extra*/)
 {
   if (PIsDescendant(&command, OpalVideoUpdatePicture)) {
-    RTP_Session * session = m_rtpSessions.GetSession(OpalMediaFormat::DefaultVideoSessionID);
-    if (session != NULL)
-      session->SendIntraFrameRequest();
+    OpalMediaStreamPtr videoStream = GetMediaStream(OpalMediaType::Video(), false);
+    if (videoStream != NULL) {
+      RTP_Session * session = m_rtpSessions.GetSession(videoStream->GetSessionID());
+      if (session != NULL) {
+        session->SendIntraFrameRequest();
 #if OPAL_STATISTICS
-    m_VideoUpdateRequestsSent++;
+        m_VideoUpdateRequestsSent++;
+      }
 #endif
+    }
   }
 }
 #else
@@ -309,10 +313,9 @@ PBoolean OpalRTPConnection::GetMediaInformation(unsigned sessionID,
   return PTrue;
 }
 
-PBoolean OpalRTPConnection::IsMediaBypassPossible(unsigned sessionID) const
+PBoolean OpalRTPConnection::IsMediaBypassPossible(unsigned) const
 {
-  return sessionID == OpalMediaFormat::DefaultAudioSessionID ||
-         sessionID == OpalMediaFormat::DefaultVideoSessionID;
+  return true;
 }
 
 OpalMediaStream * OpalRTPConnection::CreateMediaStream(const OpalMediaFormat & mediaFormat,
@@ -350,9 +353,9 @@ void OpalRTPConnection::OnPatchMediaStream(PBoolean isSource, OpalMediaPatch & p
 
 void OpalRTPConnection::OnUserInputInlineRFC2833(OpalRFC2833Info & info, INT type)
 {
-  // trigger on end of tone
+  // trigger on start of tone only
   if (type == 0)
-    OnUserInputTone(info.GetTone(), info.GetDuration()/8);
+    OnUserInputTone(info.GetTone(), info.GetDuration() > 0 ? info.GetDuration()/8 : 100);
 }
 
 void OpalRTPConnection::OnUserInputInlineCiscoNSE(OpalRFC2833Info & /*info*/, INT)
