@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20745 $
- * $Author: rjongbloed $
- * $Date: 2008-08-28 02:20:52 +0200 (jeu 28 aoû 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #include <ptlib.h>
@@ -34,6 +34,8 @@
 #pragma implementation "transcoders.h"
 #endif
 
+#include <opal/buildopts.h>
+
 #include <opal/transcoders.h>
 
 
@@ -120,7 +122,7 @@ RTP_DataFrame::PayloadTypes OpalTranscoder::GetPayloadType(PBoolean input) const
 }
 
 
-#ifdef OPAL_STATISTICS
+#if OPAL_STATISTICS
 void OpalTranscoder::GetStatistics(OpalMediaStatistics & /*statistics*/) const
 {
 }
