@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21097 $
- * $Author: dsandras $
- * $Date: 2008-09-21 11:15:43 +0000 (Sun, 21 Sep 2008) $
+ * $Revision$
+ * $Author$
+ * $Date$
  */
 
 #include <ptlib.h>
@@ -226,43 +226,51 @@ SIPURL::SIPURL(const PString & name,
                const OpalTransportAddress & address,
                WORD listenerPort)
 {
-  if (strncmp(name, "sip:", 4) == 0 || strncmp(name, "sips:", 5) == 0)
+  if (strncmp(name, "sip:", 4) == 0 || strncmp(name, "sips:", 5) == 0 || address.IsEmpty())
     Parse(name);
   else {
     PIPSocket::Address ip;
     WORD port;
     if (address.GetIpAndPort(ip, port)) {
+      PString transProto;
+      WORD defaultPort = 5060;
+
       PStringStream s;
-      s << "sip:" << name << '@';
+      s << "sip";
+
+      PCaselessString proto = address.Left(address.Find('$'));
+      if (proto == "tcps") {
+        defaultPort = 5061;
+        s << 's';
+        // use default tranport=UDP
+      }
+      else if (proto != "udp")
+        transProto = proto; // Typically "tcp"
+      // else use default UDP
+
+      s << ':' << name << '@';
       if (ip.GetVersion() == 6)
         s << '[' << ip << ']';
       else
         s << ip;
-      s << ':';
-      if (listenerPort != 0)
-        s << listenerPort;
-      else
-        s << port;
-      s << ";transport=";
-      if (strncmp(address, "tcp", 3) == 0)
-        s << "tcp";
-      else
-        s << "udp";
+
+      if (listenerPort == 0)
+        listenerPort = port;
+      if (listenerPort != 0 && listenerPort != defaultPort)
+        s << ':' << listenerPort;
+
+      if (!transProto.IsEmpty())
+        s << ";transport=" << transProto;
+
       Parse(s);
     }
   }
 }
 
 
-PBoolean SIPURL::InternalParse(const char * cstr, const char * _defaultScheme)
+PBoolean SIPURL::InternalParse(const char * cstr, const char * p_defaultScheme)
 {
-  PString defaultScheme;
-  if (_defaultScheme != NULL) 
-    defaultScheme = _defaultScheme;
-  else if (strncmp(cstr, "sips:", 5) == 0)
-    defaultScheme = "sips";
-  else 
-    defaultScheme = "sip";
+  PString defaultScheme = p_defaultScheme != NULL ? p_defaultScheme : "sip";
 
   displayName = PString::Empty();
   fieldParameters = PString::Empty();
@@ -270,63 +278,42 @@ PBoolean SIPURL::InternalParse(const char * cstr, const char * _defaultScheme)
   PString str = cstr;
 
   // see if URL is just a URI or it contains a display address as well
-  PINDEX start = str.FindLast('<');
-  PINDEX end = str.FindLast('>');
+  PINDEX startBracket = str.FindLast('<');
+  PINDEX endBracket = str.Find('>', startBracket);
 
   // see if URL is just a URI or it contains a display address as well
-  if (start == P_MAX_INDEX || end == P_MAX_INDEX) {
-    if (!PURL::InternalParse(cstr, defaultScheme)) {
-      return PFalse;
-    }
+  if (startBracket == P_MAX_INDEX || endBracket == P_MAX_INDEX) {
+    if (!PURL::InternalParse(cstr, defaultScheme))
+      return false;
   }
   else {
     // get the URI from between the angle brackets
-    if (!PURL::InternalParse(str(start+1, end-1), defaultScheme))
+    if (!PURL::InternalParse(str(startBracket+1, endBracket-1), defaultScheme))
       return PFalse;
 
-    fieldParameters = str.Mid(end+1).Trim();
+    fieldParameters = str.Mid(endBracket+1).Trim();
 
-    // extract the display address
-    end = str.FindLast('"', start);
-    start = str.FindLast('"', end-1);
-    // There are no double quotes around the display name
-    if (start == P_MAX_INDEX && end == P_MAX_INDEX) {
-      
-      displayName = str.Left(start-1).Trim();
-      start = str.FindLast ('<');
-      
-      // See if there is something before the <
-      if (start != P_MAX_INDEX && start > 0)
-        displayName = str.Left(start).Trim();
-      else { // Use the url as display name
-        end = str.FindLast('>');
-        if (end != P_MAX_INDEX)
-          str = displayName.Mid ((start == P_MAX_INDEX) ? 0:start+1, end-1);
-
-        /* Remove the tag from the display name, if any */
-        end = str.Find (';');
-        if (end != P_MAX_INDEX)
-          str = str.Left (end);
-
-        displayName = str;
-        displayName.Replace  ("sip:", "");
-      }
+    // See if display address quoted
+    PINDEX endQuote = str.FindLast('"', startBracket);
+    PINDEX startQuote = str.Find('"');
+    if (startQuote == P_MAX_INDEX || endQuote == P_MAX_INDEX || startQuote >= endQuote) {
+      // There are no double quotes around the display name, so take
+      // everything before the start angle bracket
+      displayName = str.Left(startBracket-1).Trim();
     }
-    else if (start != P_MAX_INDEX && end != P_MAX_INDEX) {
-      // No trim quotes off
-      displayName = str(start+1, end-1);
-      while ((start = displayName.Find('\\')) != P_MAX_INDEX)
-        displayName.Delete(start, 1);
+    else {
+      // Trim quotes off
+      displayName = str(startQuote+1, endQuote-1);
+      PINDEX backslash;
+      while ((backslash = displayName.Find('\\')) != P_MAX_INDEX)
+        displayName.Delete(backslash, 1);
     }
   }
 
-  if (!(scheme *= defaultScheme))
-    return PURL::Parse("");
-
-//  if (!paramVars.Contains("transport"))
-//    SetParamVar("transport", "udp");
-
-  Recalculate();
+  if (scheme == "sip" || scheme == "sips")
+    Recalculate();
+  else
+    PURL::Parse("");
   return !IsEmpty();
 }
 
@@ -426,12 +413,12 @@ void SIPURL::Sanitise(UsageContext context)
     const char * name;
     unsigned     contexts;
   } const SanitaryFields[] = {
-    { "method",    (1<<RequestURI)|(1<<ToURI)|(1<<FromURI)|(1<<ContactURI)|(1<<RouteURI) },
+    { "method",    (1<<RequestURI)|(1<<ToURI)|(1<<FromURI)|(1<<ContactURI)|(1<<RouteURI)|(1<<RegisterURI) },
     { "maddr",     (1<<ToURI)|(1<<FromURI) },
-    { "ttl",       (1<<ToURI)|(1<<FromURI)|(1<<RouteURI) },
+    { "ttl",       (1<<ToURI)|(1<<FromURI)|(1<<RouteURI)|(1<<RegisterURI) },
     { "transport", (1<<ToURI)|(1<<FromURI) },
-    { "lr",        (1<<ToURI)|(1<<FromURI)|(1<<ContactURI) },
-    { "tag",       (1<<RequestURI)|(1<<ContactURI)|(1<<RouteURI)|(1<<ExternalURI) }
+    { "lr",        (1<<ToURI)|(1<<FromURI)|(1<<ContactURI)|(1<<RegisterURI) },
+    { "tag",       (1<<RequestURI)|(1<<ContactURI)|(1<<RouteURI)|(1<<ExternalURI)|(1<<RegisterURI) }
   };
 
   for (PINDEX i = 0; i < PARRAYSIZE(SanitaryFields); i++) {
@@ -445,6 +432,11 @@ void SIPURL::Sanitise(UsageContext context)
   if (context == ToURI || context == FromURI)
     port = (scheme *= "sips") ? 5061 : 5060;
 
+  if (context == RegisterURI) {
+    username.MakeEmpty();
+    password.MakeEmpty();
+  }
+
   Recalculate();
 }
 
@@ -623,12 +615,14 @@ PString SIPMIMEInfo::GetContact() const
 }
 
 
-bool SIPMIMEInfo::GetContacts(std::vector<SIPURL> & contacts) const
+bool SIPMIMEInfo::GetContacts(std::list<SIPURL> & contacts) const
 {
   PStringArray lines = GetString("Contact").Lines();
-  contacts.resize(lines.GetSize());
-  for (PINDEX i = 0; i < lines.GetSize(); i++)
-    contacts[i].Parse(lines[i]);
+  for (PINDEX i = 0; i < lines.GetSize(); i++) {
+    PStringArray items = lines[i].Tokenise(',');
+    for (PINDEX j = 0; j < items.GetSize(); j++)
+      contacts.push_back(items[j]);
+  }
 
   return !contacts.empty();
 }
@@ -1151,6 +1145,20 @@ SIPAuthentication::SIPAuthentication()
 }
 
 
+PObject::Comparison SIPAuthentication::Compare(const PObject & other) const
+{
+  const SIPAuthentication * otherAuth = dynamic_cast<const SIPAuthentication *>(&other);
+  if (otherAuth == NULL)
+    return LessThan;
+
+  Comparison result = GetUsername().Compare(otherAuth->GetUsername());
+  if (result != EqualTo)
+    return result;
+
+  return GetPassword().Compare(otherAuth->GetPassword());
+}
+
+
 PString SIPAuthentication::GetAuthParam(const PString & auth, const char * name) const
 {
   PString value;
@@ -1246,13 +1254,20 @@ SIPDigestAuthentication & SIPDigestAuthentication::operator =(const SIPDigestAut
   return *this;
 }
 
-bool SIPDigestAuthentication::EquivalentTo(const SIPAuthentication & _oldAuth)
+PObject::Comparison SIPDigestAuthentication::Compare(const PObject & other) const
 {
-  const SIPDigestAuthentication * oldAuth = dynamic_cast<const SIPDigestAuthentication *>(&_oldAuth);
-  PAssert(oldAuth != NULL, "Cannot compare auths of different classes");
+  const SIPDigestAuthentication * otherAuth = dynamic_cast<const SIPDigestAuthentication *>(&other);
+  if (otherAuth == NULL)
+    return LessThan;
 
-  return GetUsername() == oldAuth->GetUsername() &&
-         GetNonce()    == oldAuth->GetNonce();
+  Comparison result = GetAuthRealm().Compare(otherAuth->GetAuthRealm());
+  if (result != EqualTo)
+    return result;
+
+  if (GetAlgorithm() != otherAuth->GetAlgorithm())
+    return GetAlgorithm() < otherAuth->GetAlgorithm() ? LessThan : GreaterThan;
+
+  return SIPAuthentication::Compare(other);
 }
 
 PBoolean SIPDigestAuthentication::Parse(const PString & _auth, PBoolean proxy)
@@ -1408,9 +1423,9 @@ class SIPNTLMAuthentication : public SIPAuthentication
   public: 
     SIPNTLMAuthentication();
 
-    bool EquivalentTo(
-      const SIPAuthentication & _oldAuth
-    );
+    virtual Comparison Compare(
+      const PObject & other
+    ) const;
 
     PBoolean Parse(
       const PString & auth,
@@ -1454,9 +1469,21 @@ SIPNTLMAuthentication::SIPNTLMAuthentication()
   domainName = "Domain";
 }
 
-bool SIPNTLMAuthentication::EquivalentTo(const SIPAuthentication & /*_oldAuth*/)
+PObject::Comparison SIPNTLMAuthentication::Compare(const PObject & other) const
 {
-  return false;
+  const SIPNTLMAuthentication * otherAuth = dynamic_cast<const SIPNTLMAuthentication *>(&other);
+  if (otherAuth == NULL)
+    return LessThan;
+
+  Comparison result = hostName.Compare(otherAuth->hostName);
+  if (result != EqualTo)
+    return result;
+
+  result = domainName.Compare(otherAuth->domainName);
+  if (result != EqualTo)
+    return result;
+
+  return SIPAuthentication::Compare(other);
 }
 
 PBoolean SIPNTLMAuthentication::Parse(const PString & /*auth*/, PBoolean /*proxy*/)
@@ -1995,8 +2022,10 @@ PBoolean SIP_PDU::Read(OpalTransport & transport)
 }
 
 
-PBoolean SIP_PDU::Write(OpalTransport & transport, const OpalTransportAddress & remoteAddress)
+PBoolean SIP_PDU::Write(OpalTransport & transport, const OpalTransportAddress & remoteAddress, const PString & localInterface)
 {
+  PWaitAndSignal mutex(transport.GetWriteMutex());
+
   if (!transport.IsOpen()) {
     PTRACE(1, "SIP\tAttempt to write PDU to closed tansport " << transport);
     return PFalse;
@@ -2009,6 +2038,9 @@ PBoolean SIP_PDU::Write(OpalTransport & transport, const OpalTransportAddress &
     }
   }
 
+  if (!localInterface.IsEmpty() && transport.GetInterface() != localInterface)
+    transport.SetInterface(localInterface);
+
   mime.SetCompactForm(false);
   PString strPDU = Build();
   if (!transport.IsReliable() && strPDU.GetLength() > 1450) {
@@ -2178,7 +2210,9 @@ PBoolean SIPTransaction::Start()
 
   state = Trying;
   retry = 0;
-  localInterface = transport.GetInterface();
+
+  if (m_localInterface.IsEmpty())
+    m_localInterface = transport.GetInterface();
 
   /* Get the address to which the request PDU should be sent, according to
      the RFC, for a request in a dialog. */
@@ -2198,7 +2232,7 @@ PBoolean SIPTransaction::Start()
   PTRACE(3, "SIP\tTransaction remote address is " << m_remoteAddress);
 
   // Use the connection transport to send the request
-  if (!Write(transport, m_remoteAddress)) {
+  if (!Write(transport, m_remoteAddress, m_localInterface)) {
     SetTerminated(Terminated_TransportError);
     return PFalse;
   }
@@ -2231,10 +2265,11 @@ PBoolean SIPTransaction::Cancel()
   PSafeLockReadWrite lock(*this);
 
   if (state == NotStarted || state >= Cancelling) {
-    PTRACE(3, "SIP\tTransaction " << mime.GetCSeq() << " cannot be cancelled.");
+    PTRACE(3, "SIP\tTransaction " << mime.GetCSeq() << " cannot be cancelled as in state " << state);
     return PFalse;
   }
 
+  PTRACE(4, "SIP\tTransaction " << mime.GetCSeq() << " cancelled.");
   completionTimer = endpoint.GetPduCleanUpTimeout();
   return ResendCANCEL();
 }
@@ -2251,10 +2286,7 @@ void SIPTransaction::Abort()
 
 bool SIPTransaction::SendPDU(SIP_PDU & pdu)
 {
-  PString oldInterface = transport.GetInterface();
-  if (transport.SetInterface(localInterface) &&
-      pdu.Write(transport, m_remoteAddress) &&
-      transport.SetInterface(oldInterface))
+  if (pdu.Write(transport, m_remoteAddress, m_localInterface))
     return true;
 
   SetTerminated(Terminated_TransportError);
@@ -2270,7 +2302,7 @@ bool SIPTransaction::ResendCANCEL()
                  mime.GetFrom(),
                  mime.GetCallID(),
                  mime.GetCSeqIndex(),
-                 localInterface);
+                 m_localInterface);
   // Use the topmost via header from the INVITE we cancel as per 9.1. 
   PStringList viaList = mime.GetViaList();
   cancel.GetMIME().SetVia(viaList.front());
@@ -2290,7 +2322,7 @@ bool SIPTransaction::ResendCANCEL()
 
 PBoolean SIPTransaction::OnReceivedResponse(SIP_PDU & response)
 {
-  // Stop the timers outside of the mutex to avoid deadlock
+  // Stop the timers with asynchronous flag to avoid deadlock
   retryTimer.Stop(false);
   completionTimer.Stop(false);
 
@@ -2309,6 +2341,9 @@ PBoolean SIPTransaction::OnReceivedResponse(SIP_PDU & response)
   // Something wrong here, response is not for the request we made!
   if (cseq.Find(MethodNames[method]) == P_MAX_INDEX) {
     PTRACE(2, "SIP\tTransaction " << cseq << " response not for " << *this);
+    // Restart timer as haven't finished yet
+    retryTimer = retryTimer.GetResetTime();
+    completionTimer = completionTimer.GetResetTime();
     return PFalse;
   }
 
@@ -2316,36 +2351,29 @@ PBoolean SIPTransaction::OnReceivedResponse(SIP_PDU & response)
   if (!lock.IsLocked())
     return PFalse;
 
-  PBoolean notCompletedFlag = state < Completed;
-  bool signalCompletionFlag = false;
-
   /* Really need to check if response is actually meant for us. Have a
      temporary cheat in assuming that we are only sending a given CSeq to one
      and one only host, so anything coming back with that CSeq is OK. This has
      "issues" according to the spec but
      */
-  if (notCompletedFlag && response.GetStatusCode()/100 == 1) {
-    PTRACE(3, "SIP\tTransaction " << cseq << " proceeding.");
+  if (IsInProgress()) {
+    if (response.GetStatusCode()/100 == 1) {
+      PTRACE(3, "SIP\tTransaction " << cseq << " proceeding.");
 
-    if (state == Trying)
-      state = Proceeding;
+      if (state == Trying)
+        state = Proceeding;
 
-    retry = 0;
-    retryTimer = retryTimeoutMax;
-    completionTimer = endpoint.GetNonInviteTimeout();
-  }
-  else {
-    if (notCompletedFlag) {
+      retry = 0;
+      retryTimer = retryTimeoutMax;
+      completionTimer = endpoint.GetNonInviteTimeout();
+    }
+    else {
       PTRACE(3, "SIP\tTransaction " << cseq << " completed.");
       state = Completed;
       statusCode = response.GetStatusCode();
+      completionTimer = endpoint.GetPduCleanUpTimeout();
     }
 
-    signalCompletionFlag = true;
-    completionTimer = endpoint.GetPduCleanUpTimeout();
-  }
-
-  if (notCompletedFlag) {
     if (connection != NULL)
       connection->OnReceivedResponse(*this, response);
     else
@@ -2355,8 +2383,10 @@ PBoolean SIPTransaction::OnReceivedResponse(SIP_PDU & response)
       OnCompleted(response);
   }
 
-  if (signalCompletionFlag)
+  if (response.GetStatusCode() >= 200) {
+    completionTimer = endpoint.GetPduCleanUpTimeout();
     completed.Signal();
+  }
 
   return PTrue;
 }
@@ -2416,7 +2446,6 @@ void SIPTransaction::SetTerminated(States newState)
   static const char * const StateNames[NumStates] = {
     "NotStarted",
     "Trying",
-    "Aborting",
     "Proceeding",
     "Cancelling",
     "Completed",
@@ -2487,13 +2516,26 @@ SIPInvite::SIPInvite(SIPConnection & connection, OpalTransport & transport, Opal
 PBoolean SIPInvite::OnReceivedResponse(SIP_PDU & response)
 {
   if (response.GetMIME().GetCSeq().Find(MethodNames[Method_INVITE]) != P_MAX_INDEX) {
-    connection->OnReceivedResponseToINVITE(*this, response);
+    if (IsInProgress())
+      connection->OnReceivedResponseToINVITE(*this, response);
 
     if (response.GetStatusCode() >= 200) {
       PSafeLockReadWrite lock(*this);
       if (!lock.IsLocked())
         return false;
 
+      if (response.GetStatusCode() < 300) {
+        // Need to update where the ACK goes to when have 2xx response
+        SIPURL dest;
+        const PStringList & routeSet = connection->GetRouteSet();
+        if (routeSet.IsEmpty())
+          dest = connection->GetRequestURI();
+        else
+          dest = routeSet.front();
+        m_remoteAddress = dest.GetHostAddress();
+        PTRACE(4, "SIP\tTransaction remote address changed to " << m_remoteAddress);
+      }
+
       // ACK constructed following 17.1.1.3
       SIPAck ack(*this, response);
       if (!SendPDU(ack))
@@ -2535,27 +2577,23 @@ SIPRegister::SIPRegister(SIPEndPoint & ep,
                          OpalTransport & trans,
                          const PStringList & routeSet,
                          const PString & id,
+                         unsigned cseq,
                          const Params & params)
   : SIPTransaction(ep, trans, params.m_minRetryTime, params.m_maxRetryTime)
 {
-  SIPURL aor = params.m_addressOfRecord;
-  PString addrStr = aor.AsQuotedString();
-  OpalTransportAddress viaAddress = ep.GetLocalURL(transport).GetHostAddress();
+  SIPURL uri = params.m_registrarAddress;
+  PString to = uri.GetUserName().IsEmpty() ? params.m_addressOfRecord : params.m_registrarAddress;
+  uri.Sanitise(SIPURL::RegisterURI);
   SIP_PDU::Construct(Method_REGISTER,
-                     "sip:"+aor.GetHostName(),
-                     addrStr,
-                     addrStr+";tag="+OpalGloballyUniqueID().AsString(),
+                     uri.AsString(),
+                     to,
+                     params.m_addressOfRecord,
                      id,
-                     endpoint.GetNextCSeq(),
-                     viaAddress);
+                     cseq,
+                     ep.GetLocalURL(transport).GetHostAddress());
 
   mime.SetProductInfo(ep.GetUserAgent(), ep.GetProductInfo());
-  SIPURL contact = params.m_contactAddress;
-  if (contact.IsEmpty())
-    contact = endpoint.GetLocalURL(trans, aor.GetUserName());
-  contact.Sanitise(SIPURL::ContactURI);
-  mime.SetContact(contact);
-
+  mime.SetContact(params.m_contactAddress);
   mime.SetExpires(params.m_expire);
 
   SetRoute(routeSet);
